IntoWritableParselyResult

Trait IntoWritableParselyResult 

pub trait IntoWritableParselyResult<T, B> {
    // Required method
    fn into_writable_parsely_result(self) -> ParselyResult<T>;
}
Helper trait to coerce values of both T: ParselyWrite and Result<T, E>: E: Into<anyhow::Error> into ParselyResult<T>. We need a trait specifically for writing because if we don’t bound the impl for T in some way there’s ambiguity: the compiler doesn’t know if

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T, E, B> IntoWritableParselyResult<T, B> for Result<T, E>
where E: Into<Error>,

Implementors

Source

impl<T, B> IntoWritableParselyResult<T, B> for T
where T: ParselyWrite<B>,